@@ -36,10 +36,11 @@ def get_graph_as_dict(model: tf.keras.Model) -> Tuple[Dict[str, Dict[str, list]]
     if isinstance(model.input, (list, tuple)):
         istransformer = True
         for inputs in model.input:
-            network_dict["new_output"][inputs.name] = inputs
+            network_dict["new_output"][inputs.name] = layer.input
     else:
-        for inputs in model.input:
-            network_dict["new_output"].update({inputs.name: inputs})
+        for layer in model.layers:
+            if isinstance(layer, tf.keras.layers.InputLayer):
+                network_dict["new_output"].update({layer.name: inputs})
     for layer in model.layers:
         if layer.name not in network_dict["input"]:
             network_dict["input"][layer.name] = []
